import { supabase } from './auth';

export async function signInWithGoogle() {
  try {
    const { data, error } = await supabase.auth.signInWithOAuth({
      provider: 'google',
      options: {
        queryParams: {
          access_type: 'offline',
          prompt: 'consent',
        },
        redirectTo: `${window.location.origin}/auth/callback`,
      },
    });

    if (error) {
      console.error('Google Sign In Error:', error);
      throw new Error(error.message);
    }

    return data;
  } catch (error: any) {
    console.error('Google Sign In Failed:', error);
    throw new Error('Failed to sign in with Google. Please try again.');
  }
}

export async function handleGoogleCallback(code: string) {
  try {
    const { data: { session }, error } = await supabase.auth.getSession();
    
    if (error) {
      console.error('Session Error:', error);
      throw error;
    }
    
    if (!session) {
      throw new Error('No session found after Google authentication');
    }

    // Create or update user profile
    const { data: profile, error: profileError } = await supabase
      .from('profiles')
      .select('*')
      .eq('id', session.user.id)
      .single();

    if (profileError && profileError.code !== 'PGRST116') {
      console.error('Profile Error:', profileError);
      throw profileError;
    }

    if (!profile) {
      const { error: insertError } = await supabase
        .from('profiles')
        .insert([
          {
            id: session.user.id,
            full_name: session.user.user_metadata.full_name,
            email: session.user.email,
            avatar_url: session.user.user_metadata.avatar_url,
            updated_at: new Date().toISOString(),
          },
        ]);

      if (insertError) {
        console.error('Profile Creation Error:', insertError);
        throw insertError;
      }
    }

    return session;
  } catch (error: any) {
    console.error('Google Callback Error:', error);
    throw new Error('Failed to complete Google authentication. Please try again.');
  }
}